@@ -1,14 +1,14 @@
 from pydantic import BaseModel
 
-from uipath.eval.models.models import EvaluatorCategory, EvaluatorType
+from uipath.eval.models.models import LegacyEvaluatorCategory, LegacyEvaluatorType
 
 
 class EvaluatorBaseParams(BaseModel):
     """Parameters for initializing the base evaluator."""
 
     id: str
-    category: EvaluatorCategory
-    evaluator_type: EvaluatorType
+    category: LegacyEvaluatorCategory
+    evaluator_type: LegacyEvaluatorType
     name: str
     description: str
     created_at: str
