@@ -8,18 +8,23 @@ from pydantic import TypeAdapter, ValidationError
 from uipath._cli._evals._models._evaluation_set import (
     EvaluationItem,
     EvaluationSet,
+    InputMockingStrategy,
     LegacyEvaluationItem,
     LegacyEvaluationSet,
+    LLMMockingStrategy,
 )
 from uipath._cli._utils._console import ConsoleLogger
 
 console = ConsoleLogger()
 
 
+EVAL_SETS_DIRECTORY_NAME = "evaluations/eval-sets"
+
+
 class EvalHelpers:
     @staticmethod
     def auto_discover_eval_set() -> str:
-        """Auto-discover evaluation set from evals/eval-sets directory.
+        """Auto-discover evaluation set from {EVAL_SETS_DIRECTORY_NAME} directory.
 
         Returns:
             Path to the evaluation set file
@@ -27,11 +32,11 @@ class EvalHelpers:
         Raises:
             ValueError: If no eval set found or multiple eval sets exist
         """
-        eval_sets_dir = Path("evals/eval-sets")
+        eval_sets_dir = Path(EVAL_SETS_DIRECTORY_NAME)
 
         if not eval_sets_dir.exists():
             raise ValueError(
-                "No 'evals/eval-sets' directory found. "
+                f"No '{EVAL_SETS_DIRECTORY_NAME}' directory found. "
                 "Please set 'UIPATH_PROJECT_ID' env var and run 'uipath pull'."
             )
 
@@ -39,7 +44,7 @@ class EvalHelpers:
 
         if not eval_set_files:
             raise ValueError(
-                "No evaluation set files found in 'evals/eval-sets' directory. "
+                f"No evaluation set files found in '{EVAL_SETS_DIRECTORY_NAME}' directory. "
             )
 
         if len(eval_set_files) > 1:
@@ -73,12 +78,12 @@ class EvalHelpers:
         Returns:
             Tuple of (EvaluationSet, resolved_path)
         """
-        # If the file doesn't exist at the given path, try looking in evals/eval-sets/
+        # If the file doesn't exist at the given path, try looking in {EVAL_SETS_DIRECTORY_NAME}/
         resolved_path = eval_set_path
         if not Path(eval_set_path).exists():
-            # Check if it's just a filename, then search in evals/eval-sets/
+            # Check if it's just a filename, then search in {EVAL_SETS_DIRECTORY_NAME}/
             if Path(eval_set_path).name == eval_set_path:
-                eval_sets_path = Path("evals/eval-sets") / eval_set_path
+                eval_sets_path = Path(EVAL_SETS_DIRECTORY_NAME) / eval_set_path
                 if eval_sets_path.exists():
                     resolved_path = str(eval_sets_path)
 
@@ -88,7 +93,7 @@ class EvalHelpers:
         except FileNotFoundError as e:
             raise ValueError(
                 f"Evaluation set file not found: '{eval_set_path}'. "
-                f"Searched in current directory and evals/eval-sets/ directory."
+                f"Searched in current directory and {EVAL_SETS_DIRECTORY_NAME}/ directory."
             ) from e
         except json.JSONDecodeError as e:
             raise ValueError(
@@ -105,14 +110,28 @@ class EvalHelpers:
                 def migrate_evaluation_item(
                     evaluation: LegacyEvaluationItem, evaluators: list[str]
                 ) -> EvaluationItem:
+                    mocking_strategy = None
+                    input_mocking_strategy = None
+                    if (
+                        evaluation.simulate_input
+                        and evaluation.input_generation_instructions
+                    ):
+                        input_mocking_strategy = InputMockingStrategy(
+                            prompt=evaluation.input_generation_instructions,
+                        )
+                    if evaluation.simulate_tools and evaluation.simulation_instructions:
+                        mocking_strategy = LLMMockingStrategy(
+                            prompt=evaluation.simulation_instructions,
+                            tools_to_simulate=evaluation.tools_to_simulate or [],
+                        )
                     return EvaluationItem.model_validate(
                         {
                             "id": evaluation.id,
                             "name": evaluation.name,
                             "inputs": evaluation.inputs,
                             "expectedAgentBehavior": evaluation.expected_agent_behavior,
-                            "mockingStrategy": evaluation.mocking_strategy,
-                            "inputMockingStrategy": evaluation.input_mocking_strategy,
+                            "mockingStrategy": mocking_strategy,
+                            "inputMockingStrategy": input_mocking_strategy,
                             "evaluationCriterias": {
                                 k: {
                                     "expectedOutput": evaluation.expected_output,
