@@ -11,7 +11,12 @@ from pydantic import BaseModel, ConfigDict, Field, field_validator
 from uipath import UiPath
 from uipath._config import UiPathConfig
 from uipath._utils._bindings import ResourceOverwrite, ResourceOverwriteParser
-from uipath._utils.constants import ENV_TENANT_ID, HEADER_SW_LOCK_KEY, HEADER_TENANT_ID
+from uipath._utils.constants import (
+    ENV_TENANT_ID,
+    HEADER_SW_LOCK_KEY,
+    HEADER_TENANT_ID,
+    STUDIO_METADATA_FILE,
+)
 from uipath.models.exceptions import EnrichedException
 from uipath.tracing import traced
 
@@ -121,8 +126,6 @@ class ProjectStructure(ProjectFolder):
         folder_type: The type of the root folder (optional)
     """
 
-    pass
-
 
 class LockInfo(BaseModel):
     model_config = ConfigDict(
@@ -146,7 +149,8 @@ class Severity(str, Enum):
 
 class VirtualResourceRequest(BaseModel):
     model_config = ConfigDict(
-        populate_by_name=True,
+        validate_by_name=True,
+        validate_by_alias=True,
     )
 
     kind: str = Field(alias="kind")
@@ -168,6 +172,71 @@ class VirtualResourceResult(BaseModel):
     message: str
 
 
+class ReferencedResourceFolder(BaseModel):
+    """Folder reference for a referenced resource.
+
+    Attributes:
+        fully_qualified_name: The fully qualified name of the folder
+        path: The path to the folder
+    """
+
+    model_config = ConfigDict(
+        validate_by_name=True,
+        validate_by_alias=True,
+    )
+
+    folder_key: str = Field(alias="folderKey")
+    fully_qualified_name: str = Field(alias="fullyQualifiedName")
+    path: str = Field(alias="path")
+
+
+type_mappings = {
+    "text": "stringAsset",
+    "integer": "integerAsset",
+    "bool": "booleanAsset",
+    "credential": "credentialAsset",
+    "secret": "secretAsset",
+    "orchestrator": "orchestratorBucket",
+    "amazon": "amazonBucket",
+    "azure": "azureBucket",
+}
+
+
+class ReferencedResourceRequest(BaseModel):
+    """Request payload for creating a referenced resource.
+
+    Attributes:
+        key: The resource key
+        kind: The kind of resource
+        type: The type of resource
+        folder: Folder of the referenced resource
+    """
+
+    model_config = ConfigDict(
+        validate_by_name=True,
+        validate_by_alias=True,
+    )
+
+    key: str = Field(alias="key")
+    kind: str = Field(alias="kind")
+    type: Optional[str] = Field(alias="type")
+    folder: ReferencedResourceFolder = Field(alias="folder")
+
+    @field_validator("kind", mode="before")
+    @classmethod
+    def lowercase_kind(cls, v: str) -> str:
+        return v[0].lower() + v[1:] if v else v
+
+    @field_validator("type", mode="before")
+    @classmethod
+    def type_mapping(cls, v: Optional[str]) -> Optional[str]:
+        if not v:
+            return v
+        if v.lower() in type_mappings:
+            return type_mappings[v.lower()]
+        return v[0].lower() + v[1:]
+
+
 class ResourceOverwriteData(BaseModel):
     """Represents the overwrite details from the API response.
 
@@ -177,7 +246,8 @@ class ResourceOverwriteData(BaseModel):
     """
 
     model_config = ConfigDict(
-        populate_by_name=True,
+        validate_by_name=True,
+        validate_by_alias=True,
     )
 
     name: str = Field(alias="name")
@@ -279,6 +349,47 @@ class ProjectLockUnavailableError(RuntimeError):
     pass
 
 
+class Status(str, Enum):
+    ADDED = "ADDED"
+    UNCHANGED = "UNCHANGED"
+    UPDATED = "UPDATED"
+
+
+class ReferencedResourceResponse(BaseModel):
+    """Response from creating a referenced resource.
+
+    Attributes:
+        status: The status of the operation
+        resource: The resource details
+        saved: Whether the resource was saved
+    """
+
+    model_config = ConfigDict(
+        validate_by_name=True,
+        validate_by_alias=True,
+    )
+
+    status: Status
+    resource: dict[str, Any]
+    saved: bool
+
+    @field_validator("status", mode="before")
+    @classmethod
+    def parse_status(cls, v: str | Status) -> Status:
+        """Parse status string to Status enum."""
+        if isinstance(v, Status):
+            return v
+        if isinstance(v, str):
+            upper_v = v.upper()
+            for status in Status:
+                if status.value == upper_v:
+                    return status
+            raise ValueError(f"Invalid status value: {v}")
+        raise ValueError(
+            f"Status must be a string or Status enum, got {type(v).__name__}"
+        )
+
+
 def with_lock_retry(func: Callable[..., Any]) -> Callable[..., Any]:
     @wraps(func)
     async def wrapper(self: "StudioClient", *args, **kwargs):
@@ -313,6 +424,7 @@ class StudioSolutionsClient:
         project_name: str,
         project_type: str = "Agent",
         trigger_type: str = "Manual",
+        description: Optional[str] = None,
     ):
         """Create a new project in the specified solution.
 
@@ -328,6 +440,7 @@ class StudioSolutionsClient:
             "createDefaultProjectCommand[projectType]": project_type,
             "createDefaultProjectCommand[triggerType]": trigger_type,
             "createDefaultProjectCommand[name]": project_name,
+            "createDefaultProjectCommand[description]": description,
         }
 
         response = await self.uipath.api_client.request_async(
@@ -340,6 +453,21 @@ class StudioSolutionsClient:
         return response.json()
 
 
+class StudioProjectMetadata(BaseModel):
+    model_config = ConfigDict(
+        validate_by_name=True,
+        validate_by_alias=True,
+        use_enum_values=True,
+        arbitrary_types_allowed=True,
+        extra="allow",
+    )
+
+    schema_version: int = Field(alias="schemaVersion")
+    last_push_date: str = Field(alias="lastPushDate")
+    last_push_author: str = Field(alias="lastPushAuthor")
+    code_version: str = Field(alias="codeVersion")
+
+
 class StudioClient:
     def __init__(self, project_id: str, uipath: Optional[UiPath] = None):
         self.uipath: UiPath = uipath or UiPath()
@@ -365,6 +493,22 @@ class StudioClient:
         self._solution_id_cache = response.json()["solutionId"]
         return self._solution_id_cache
 
+    async def get_project_metadata_async(self) -> Optional[StudioProjectMetadata]:
+        structure = await self.get_project_structure_async()
+        folder = get_folder_by_name(structure, ".uipath")
+        if not folder:
+            return None
+        try:
+            file = next(
+                file for file in folder.files if file.name == STUDIO_METADATA_FILE
+            )
+        except StopIteration:
+            return None
+        response = await self.download_project_file_async(file)
+        return StudioProjectMetadata.model_validate_json(
+            response.read().decode("utf-8")
+        )
+
     async def _get_existing_resources(self) -> List[dict[str, Any]]:
         if self._resources_cache is not None:
             return self._resources_cache
@@ -511,6 +655,32 @@ class StudioClient:
         message = f"{base_message} created successfully."
         return VirtualResourceResult(severity=Severity.SUCCESS, message=message)
 
+    async def create_referenced_resource(
+        self, referenced_resource_request: ReferencedResourceRequest
+    ) -> ReferencedResourceResponse:
+        """Create a referenced resource.
+
+        Args:
+            referenced_resource_request: The referenced resource request details
+
+        Returns:
+            ReferencedResourceResponse: Serialized response with status, resource details, and saved flag
+        """
+        tenant_id = os.getenv(ENV_TENANT_ID, None)
+
+        solution_id = await self._get_solution_id()
+        response = await self.uipath.api_client.request_async(
+            "POST",
+            url=f"/studio_/backend/api/resourcebuilder/solutions/{solution_id}/resources/reference",
+            scoped="org",
+            json=referenced_resource_request.model_dump(
+                by_alias=True, exclude_none=True
+            ),
+            headers={HEADER_TENANT_ID: tenant_id},
+        )
+
+        return ReferencedResourceResponse.model_validate(response.json())
+
     async def _update_resource_specs(
         self, resource_key: str, new_specs: dict[str, Any]
     ):
