@@ -3,7 +3,6 @@ import logging
 
 import click
 
-from ..telemetry import track
 from ._evals._helpers import register_evaluator
 from ._utils._console import ConsoleLogger
 from ._utils._resources import Resources
@@ -15,7 +14,6 @@ console = ConsoleLogger()
 @click.command()
 @click.argument("resource", required=True)
 @click.argument("args", nargs=-1)
-@track
 def register(resource: str, args: tuple[str]) -> None:
     """Register a local resource.
 
