@@ -1,7 +1,7 @@
 import json
 import logging
 from pathlib import Path, PurePath
-from typing import Any
+from typing import Any, Optional
 
 from httpx import Response
 from pydantic import TypeAdapter
@@ -10,7 +10,7 @@ from uipath._cli._utils._constants import (
     EVALS_DIRECTORY_NAME,
 )
 from uipath._cli._utils._eval_set import EvalHelpers
-from uipath._cli._utils._project_files import pull_project  # type: ignore[attr-defined]
+from uipath._cli._utils._project_files import pull_project
 from uipath._cli._utils._studio_project import (
     ProjectFile,
     ProjectFolder,
@@ -34,9 +34,13 @@ async def get_file(
     return await studio_client.download_project_file_async(resolved)
 
 
-async def create_agent_project(solution_id: str, project_name: str) -> str:
+async def create_agent_project(
+    solution_id: str, project_name: str, description: Optional[str] = None
+) -> str:
     studio_client = StudioSolutionsClient(solution_id=solution_id)
-    project = await studio_client.create_project_async(project_name=project_name)
+    project = await studio_client.create_project_async(
+        project_name=project_name, description=description
+    )
     return project["id"]
 
 
@@ -50,12 +54,15 @@ async def download_agent_project(
         project_id: The project ID to download from
         target_project_dir: Directory where files will be downloaded
     """
-    default_download_configuration = {
+    default_download_configuration: dict[str | None, Path] = {
         None: target_project_dir,
     }
 
+    studio_client = StudioClient(project_id)
     logger.info(f"Downloading project {project_id}...")
-    async for update in pull_project(project_id, default_download_configuration):
+    async for update in pull_project(
+        project_id, default_download_configuration, studio_client
+    ):
         logger.info(update.message)
 
     logger.info(f"Successfully downloaded project {project_id}.")
